# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic

from ...core.pydantic_utilities import UniversalBaseModel
from .transcription_info import TranscriptionInfo


class TranscriptionRequest(UniversalBaseModel):
    audio_url: str = pydantic.Field()
    """
    URL to the audio file
    """

    audio_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    ID of the audio file (for audio in the S3 bucket, this is the postgres storage metadata id)
    """

    info: TranscriptionInfo = pydantic.Field()
    """
    Transcription parameters
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
