# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic

from ...core.pydantic_utilities import UniversalBaseModel
from .timestamp import Timestamp
from .transcription_info import TranscriptionInfo


class Transcription(UniversalBaseModel):
    text: str = pydantic.Field()
    """
    Transcription text. if the `primary_language` was English and only one `lang_for_hebrew_words` was specified,
    this is just the English text with whatever language for the words you specified.
    If you set multiple `lang_for_hebrew_words`,
    this is the text with Hebrew words, with the English text in <i>Italics</i> markup.
    If primary language is Hebrew, this is just the Hebrew text.
    """

    timestamps: typing.Optional[typing.List[Timestamp]] = pydantic.Field(default=None)
    """
    Timestamps for the transcription text
    """

    info: TranscriptionInfo = pydantic.Field()
    """
    Additional information about the transcription
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
