# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic

from ...core.pydantic_utilities import UniversalBaseModel
from .language import Language


class Timestamp(UniversalBaseModel):
    word: str = pydantic.Field()
    """
    Word
    """

    punctuated_word: typing.Optional[str] = pydantic.Field(default=None)
    """
    Punctuated word
    """

    languages: typing.Optional[typing.List[Language]] = pydantic.Field(default=None)
    """
    Language for the transcription that this timestamp belongs to
    """

    start: float = pydantic.Field()
    """
    Start time of the timestamp
    """

    end: float = pydantic.Field()
    """
    End time of the timestamp
    """

    speaker: typing.Optional[str] = pydantic.Field(default=None)
    """
    Speaker (Pro feature)
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
