# This file was auto-generated by Fern from our API Definition.

import typing

Status = typing.Union[
    typing.Literal["RECEIVED", "PENDING", "PROCESSING", "COMPLETED", "CANCELLED", "FAILED"], typing.Any
]
