# This file was auto-generated by Fern from our API Definition.

import typing
import uuid

import pydantic

from ...core.pydantic_utilities import UniversalBaseModel


class Usage(UniversalBaseModel):
    id: uuid.UUID = pydantic.Field()
    """
    ID of the user
    """

    seconds_remaining: float = pydantic.Field()
    """
    Seconds remaining for the user
    """

    organization_id: typing.Optional[uuid.UUID] = pydantic.Field(default=None)
    """
    ID of the organization the user belongs to
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
